@@ -21,7 +21,7 @@ class ISBNToolsException(Exception):
     """
 
     def __str__(self):
-        return getattr(self, 'message', '')   # pragma: no cover
+        return getattr(self, 'message', '')      # pragma: no cover
 
 
 class NotRecognizedServiceError(ISBNToolsException):
@@ -40,7 +40,7 @@ class NotValidISBNError(ISBNToolsException):
         self.message = "(%s) is not a valid ISBN" % isbnlike
 
 
-class PluginNotLoadedError(ISBNToolsException):
+class PluginNotLoadedError(ISBNToolsException):  # pragma: no cover
     """ Exception raised when the plugin's loader doesn't load the plugin
     """
 
