@@ -8,6 +8,7 @@ try:                                 # pragma: no cover
 except ImportError:                  # pragma: no cover
     import ConfigParser as configparser
 import socket
+from pkg_resources import iter_entry_points
 from . import in_virtual
 from . import config
 from . import registry
@@ -105,6 +106,13 @@ try:
 except:                              # pragma: no cover
     pass
 
+# get plugins from entry_points
+try:                                 # pragma: no cover
+    for entry in iter_entry_points(group='isbntools.plugins'):
+        registry.add_service(entry.name, entry.load())
+except:                              # pragma: no cover
+    pass
+
 # socket timeout is not exposed at urllib2 level so I had to import the
 # module and set a default value for all the sockets (timeout in seconds)
 # however this should be done at top level due to strong side effects...
